@@ -9,5 +9,5 @@ def get_course_overview():
     try:
         from openedx.core.djangoapps.content.course_overviews.models import CourseOverview
     except ImportError:
-        from eox_tagging.test.test_utils import CourseOverview
+        CourseOverview = object
     return CourseOverview
